Element

Struct Element 

pub struct Element {
    pub name: QualName,
    pub attrs: Vec<Attr>,
    pub template_contents: Option<NodeId>,
    pub mathml_annotation_xml_integration_point: bool,
}
An element with attributes.

Fields

name: QualNameattrs: Vec<Attr>template_contents: Option<NodeId>

For HTML <template> elements, the template contents.

mathml_annotation_xml_integration_point: bool

Whether the element is a MathML annotation-xml integration point.

This is set by the parser when an annotation-xml element in the MathML namespace has an encoding of text/html or application/xhtml+xml (ASCII case-insensitive), making it an integration point for HTML. See the HTML parsing spec for “MathML annotation-xml integration points”.

Implementations

Source

impl Element

pub fn new( name: QualName, attrs: Vec<Attribute>, template_contents: Option<NodeId>, mathml_annotation_xml_integration_point: bool, ) -> Element

Create a new element.

pub fn node_name(&self) -> StrTendril

The name of the node.

pub fn class(&self) -> Option<StrTendril>

Get the class attribute of the node.

pub fn id(&self) -> Option<StrTendril>

Get the id attribute of the node.

pub fn has_class(&self, class: &str) -> bool

Whether the element has the given class.

pub fn has_class_bytes( &self, name: &[u8], case_sensitivity: CaseSensitivity, ) -> bool

Whether the element has the given class.

pub fn add_class(&mut self, classes: &str)

Add a class to the element.

pub fn remove_class(&mut self, class: &str)

Remove a class from the element.

pub fn attr(&self, name: &str) -> Option<StrTendril>

Gets the specified attribute’s value.

pub fn set_attr(&mut self, name: &str, val: &str)

Sets the specified attribute’s value.

pub fn remove_attr(&mut self, name: &str)

Removes the specified attribute from the element.

pub fn remove_attrs(&mut self, names: &[&str])

Removes the specified attributes from the element.

Arguments
  • names: A slice of attribute names to remove. Empty slice removes no attributes.
pub fn retain_attrs(&mut self, names: &[&str])

Retains only the attributes with the specified names.

Arguments
  • names: A slice of attribute names to retain. Empty slice retains no attributes.
pub fn remove_all_attrs(&mut self)

Removes all attributes from the element.

pub fn has_attr(&self, name: &str) -> bool

Checks if the element has an attribute with the name.

pub fn attr_ref(&self, local_name: LocalName) -> Option<&str>

Retrieves the value of an attribute by the given LocalName.

pub fn rename(&mut self, name: &str)

Renames the element.

If element is a link.