Node

Type Alias Node 

pub type Node<'a> = NodeRef<'a>;
An alias for NodeRef that is used in public API.

Aliased Type

pub struct Node<'a> {
    pub id: NodeId,
    pub tree: &'a Tree,
}

Fields

id: NodeId

The actual index of the node in the tree used to access it in the tree.

tree: &'a Tree

The reference to the tree to which the node belongs.