pub type Node<'a> = NodeRef<'a>;Expand description
An alias for NodeRef that is used in public API.
Aliased Type
pub struct Node<'a> {
pub id: NodeId,
pub tree: &'a Tree,
}Fields
id: NodeIdThe actual index of the node in the tree used to access it in the tree.
tree: &'a TreeThe reference to the tree to which the node belongs.